function [PSNR MSE E] = errorMedida(origImg, distImg)
% Calcula el PSNR E MSE de dos imgenes

% Calculo de dimensiones
[MA NA DIMA] = size(origImg);
[MB NB DIMB] = size(distImg);

% Comprobacin de dimensiones
if( (MA ~= MB) || (NA ~= NB) || (DIMA ~= DIMB) )
    fprintf('\n DIMENSIONES DE LAS IMGENES NO COINCIDEN');
    fprintf('\n %dx%dx%d != %dx%dx%d', MA, NA, DIMA, MB, NB, DIMB);
    E=-1;
    MSE=-1;
    PSNR=-1;
    return
end

% Imagen error
error = abs(double(origImg) - double(distImg));

% Error total
E=sum(sum(sum(error)));

% RMS
MSE = sqrt(sum(sum(sum( error.^2))) / (MA * NA * DIMA));

% PSNR
if(MSE > 0)
    PSNR = 10*log10(255*255/MSE^2);
else
    PSNR = inf;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                                                              %%
%% COMPRESION DE VIDEO                                          %%
%% Grado en Ingeniera de Tecnologas de Telecomunicacin       %%
%% Gustavo A. Ruiz Robredo                                      %%
%% ruizrg@unican.es                                             %%
%%                                                              %%
%% uu   uu  cccccc   UNIVERSIDAD DE CANTABRIA                   %%
%% uu   uu  cccccc   Dpto. INGENIERIA INFORMATICA Y ELECTRONICA %%
%% uu   uu  cc       FACULTAD DE CIENCIAS                       %%
%%  uuuuu   cccccc   Avda. Los Castros s/n                      %%
%%   uuu    cccccc   39005-SANTANDER (SPAIN)                    %%
%%                                                              %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
